@@ -11,8 +11,8 @@ package Dist::Zilla::Plugin::ContributorsFromGit;
 BEGIN {
   $Dist::Zilla::Plugin::ContributorsFromGit::AUTHORITY = 'cpan:RSRCHBOY';
 }
-# git description: 0.008-3-ga9e3714
-$Dist::Zilla::Plugin::ContributorsFromGit::VERSION = '0.009';
+# git description: 0.009-11-gb15a4e1
+$Dist::Zilla::Plugin::ContributorsFromGit::VERSION = '0.010';
 
 # ABSTRACT: Populate your 'CONTRIBUTORS' POD from the list of git authors
 
@@ -40,10 +40,7 @@ with
     'Dist::Zilla::Role::MetaProvider',
     ;
 
-# debugging...
-#use Smart::Comments '###';
-
-has contributor_list => (
+has _contributor_list => (
     is      => 'lazy',
     isa     => 'ArrayRef[Str]',
     builder => sub {
@@ -52,10 +49,11 @@ has contributor_list => (
 
         ### and get our list from git, filtering: "@authors"
         my @contributors = uniq
-            map   { $self->author_emails->{$_} // $_    }
-            grep  { $_ ne 'Your Name <you@example.com>' }
-            grep  { @authors->none eq $_                }
-            apply { chomp; s/\s*\d+\s*//; $_ = decode_utf8($_) }
+            map  { $self->_contributor_emails->{$_} // $_ }
+            grep { $_ ne 'Your Name <you@example.com>'   }
+            grep { @authors->none eq $_                  }
+            map  { decode_utf8($_)                       }
+            map  { chomp; s/^\s*\d+\s*//; $_             }
             `git shortlog -s -e`
             ;
 
@@ -63,25 +61,25 @@ has contributor_list => (
     },
 );
 
-
-has author_emails => (
+has _contributor_emails => (
     is       => 'lazy',
     isa      => HashRef[Str],
     init_arg => undef,
 
     builder => sub {
 
-        my $mapping = YAML::Tiny->read(
-            file(
-                dist_dir('Dist-Zilla-Plugin-ContributorsFromGit'),
-                'author-emails.yaml',
-            ))
+        my $mapping = YAML::Tiny
+            ->read(
+                file(
+                    dist_dir('Dist-Zilla-Plugin-ContributorsFromGit'),
+                    'author-emails.yaml',
+                ),
+            )
             ->[0]
             ;
 
         my $_map_it = sub {
             my ($canonical, @alternates) = @_;
-
             return ( map { $_ => $canonical } @alternates );
         };
 
@@ -109,7 +107,7 @@ sub before_build {
     do { $stash = PodWeaver->new; $self->_register_stash('%PodWeaver', $stash) }
         unless defined $stash;
     my $config       = $stash->_config;
-    my @contributors = $self->contributor_list->flatten;
+    my @contributors = $self->_contributor_list->flatten;
 
     my $i = 0;
     do { $config->{"Contributors.contributors[$i]"} = $_; $i++ }
@@ -130,7 +128,7 @@ sub before_build {
 
 sub metadata {
     my $self = shift @_;
-    my $list = $self->contributor_list;
+    my $list = $self->_contributor_list;
     return @$list ? { 'x_contributors' => $list } : {};
 }
 
@@ -146,6 +144,7 @@ __END__
 =for :stopwords Chris Weyl David Golden Graham Knop Randy Stauner Tatsuhiko Miyagawa
 <dagolden@cpan.org> <haarg@haarg.org> <randy@magnificent-tears.com>
 <miyagawa@bulknews.net> zilla BeforeBuild metacpan shortlog committer
+mailmap
 
 =head1 NAME
 
@@ -153,7 +152,7 @@ Dist::Zilla::Plugin::ContributorsFromGit - Populate your 'CONTRIBUTORS' POD from
 
 =head1 VERSION
 
-This document describes version 0.009 of Dist::Zilla::Plugin::ContributorsFromGit - released April 08, 2014 as part of Dist-Zilla-Plugin-ContributorsFromGit.
+This document describes version 0.010 of Dist::Zilla::Plugin::ContributorsFromGit - released April 08, 2014 as part of Dist-Zilla-Plugin-ContributorsFromGit.
 
 =head1 SYNOPSIS
 
@@ -184,40 +183,54 @@ added if it is not found.  However, your L<Pod::Weaver> config (aka
 c<weaver.ini>) must include the
 L<Contributors|Pod::Weaver::Section::Contributors> section plugin.
 
+=head2 Dist::Zilla Phase
+
 This plugin runs during the L<BeforeBuild|Dist::Zilla::Role::BeforeBuild>
 phase.
 
+=head2 Metadata Keys
+
 The list of contributors is also added to distribution metadata under the custom
-C<x_contributors> key.
-
-=head1 ATTRIBUTES
-
-=head2 author_emails
-
-This is an hash of additional emails that may be found from time to time in
-git commit logs mapped back to the author's 'canonical' author email.
-Generally speaking, the 'canonical email' will be the author's C<@cpan.org>
-address, so that C<metacpan> may properly attribute contributions.
-
-e.g.
-
-    {
-        'Chris Weyl <cweyl@alumni.drew.edu>' => 'Chris Weyl <rsrchboy@cpan.org>',
-        'Chris Weyl <chris.weyl@wps.io>'     => 'Chris Weyl <rsrchboy@cpan.org>',
-        ...
-    }
-
-Note that this attribute is *read-only*; its contents are loaded from
-C<share/author-emails.yaml>. B<please> fork and send a pull
-request if you'd like to add additional mappings.  This is highly
-encouraged. :)
-
-=for Pod::Coverage before_build metadata
+C<x_contributors> key.  (e.g. in C<META.yml>, C<META.json>, etc)
 
 If you have duplicate contributors because of differences in committer name
 or email you can use a C<.mailmap> file to canonicalize contributor names
 and emails.  See L<git help shortlog|git-shortlog(1)> for details.
 
+=for Pod::Coverage before_build metadata
+
+=head1 METACPAN CONTRIBUTOR MATCHING
+
+L<MetaCPAN|http://metacpan.org> will attempt to match a contributor address
+back to a PAUSE account.  However, it (currently) can only do that if the
+contributor's email address is their C<PAUSEID@cpan.org> address.  There are
+two mechanisms for helping to resolve this, if your commits are not using this
+address.
+
+Both of these approaches have pros and cons that have been discussed at
+levels nearing the heat brought to any discussion of religion, homosexuality,
+or Chief O'Brien's actual rank at any ST:TNG convention.  However, they both
+have the advantage of *working*, and through different modes of action.  You
+are free to use one, both or neither.  These are only important if you're not
+committing with your C<@cpan.org> email address B<and> want the MetaCPAN to
+link to your author page from the page of the package you contributed to.
+
+=head2 Using a .mailmap file
+
+See C<git help shortlog> for help on how to use this.  A C<.mailmap> file must
+be maintained in each repository using it.
+
+=head2 Globally, via the authors mapping
+
+This package contains a YAML file containing a mapping of C<@cpan.org> author
+addresses; this list is consulted while building the contributors list, and
+can be used to replace a non-cpan.org address with one.
+
+To add to or modify this mapping, please feel free to fork, add your alternate
+email addresses to C<share/author-emails.yaml>, and submit a pull-request for
+inclusion.  It'll be merged and released; as various authors update their set
+of installed modules and cut new releases, the mapping will appear.
+
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
